@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# velobox_update_3.0.3
+# velobox_update_3.0.4
 # Einspielen aller Dateien in /usr/local/vmkstationd3/
 # Velometrik-GmbH
 # Breunsdorfer Str. 48a
@@ -10,10 +10,10 @@
 # support@velometrik.de
 #
 # Historie:
-# 31.03.2023	Björn Bauer	erstellt
+# 12.06.2023	Björn Bauer	erstellt
 
-LAST_VERSION=3.0.2
-CURRENT_VERSION=3.0.3
+LAST_VERSION=3.0.3
+CURRENT_VERSION=3.0.4
 
 if [ `whoami` != "root" ]; then
 echo "ERROR"
@@ -27,14 +27,6 @@ echo "ERROR"
 	exit 1
 fi
 
-echo "Delete htdocs"
-rm -r /usr/local/vmkstationd3/htdocs/
-if [ $? -ne 0 ]; then
-echo "ERROR"
-	echo "The folder "htdocs" could not be deleted!"
-	exit 1
-fi
-
 echo "Files in / will be installed."
 if [ ! -r velobox_update_$CURRENT_VERSION.tar.gz ]; then
 echo "ERROR"
@@ -56,7 +48,33 @@ test $? -ne 0 && exit 1
 rm -f velobox_update_$CURRENT_VERSION.tar.gz
 
 echo "Files in / were recorded."
+        
+echo "Delete current symbolic link to vmkstationd"
+rm /usr/local/vmkstationd
+if [ $? -ne 0 ]; then
+echo "ERROR"
+    echo "error at # rm /usr/local/vmkstationd"
+    exit 1
+fi
+echo "done"
 
+echo "Create symbolic link to vmkstationd"
+ln -s /usr/local/vmkstationd3.1.0_U/ /usr/local/vmkstationd
+if [ $? -ne 0 ]; then
+echo "ERROR"
+    echo "error at # ln -s /usr/local/vmkstationd3.1.0_U/ /usr/local/vmkstationd"
+    exit 1
+fi
+echo "done"        
+
+echo "Delete vmkstationd3"
+rm -r /usr/local/vmkstationd3/
+if [ $? -ne 0 ]; then
+echo "ERROR"
+	echo "The folder "/usr/local/vmkstationd3/" could not be deleted!"
+	exit 1
+fi      
+        
 ### Do not change anything from here on! ###
 
 #################################
